==> ij-rubik-1.71.0.tgz: package/README.md <==
[![Build Status](https://travis.mpi-internal.com/scmspain/frontend-ij--lib-rubik.svg?token=weuzuyzw6juAMe8gcwxy&branch=master)](https://travis.mpi-internal.com/scmspain/frontend-ij--rubik) ![](https://img.shields.io/badge/automatic-release-brightgreen)


# RubikJS

## Description

JavaScript library meant to abstract core functionality in our [beloved monolith](https://github.schibsted.io/scmspain/all-ij--web-empleo)

## Usage

### Load the script at the end of the body tag in your html file

```html
<html>
<head>
  ...
</head>
<body>
  ...
  <!-- PRE ENVS -->
  <script src="https://unpkg.com/@s-ui/ij-rubik@next/umd/index.js"></script>
  <!-- PRO ENV -->
  <script src="https://unpkg.com/@s-ui/ij-rubik/umd/index.js"></script>
</body>
</html>
```

### Local dev

1. Create new umd

```shell
> npm run umd:dev
```

2. Open a http server serving the umd folder

> ⚠️ make sure the server runs in port 5000

``` shell
> npx serve umd
```

3. Open the production page and block the `https://unpkg.com/@s-ui/ij-rubik/umd/index.js` file

4. Run this script to load rubik

```js
var script = document.createElement('script');
script.src = 'http://localhost:5000/index.js'
body.append(script)
```

You can also test the library by publishing a new beta version. In order to do that:

1. Put the **-next.0** suffix to your version

```default
"version": "1.50.0-next.0",
```

2. Execute the publish command

``` shell
> npm publish --tag next
```

3. Check this url **https://unpkg.com/@s-ui/ij-rubik@next/umd/index.js**. In few minutes, it should be redirect to your beta version. In our case:

```default
https://unpkg.com/@s-ui/ij-rubik@1.50.0-next.0/umd/index.js
```

### Release a new version

Once you have merged your changes, the @s-ui/ci tool will automatically release your component. Once this step is completed **https://unpkg.com/@s-ui/ij-rubik/umd/index.js** will need up to 20 minutes to update its cdn's cache and start deliver the new version.


### Listen to `rubik:loaded` event rubik will sent once its loaded

```js
document.addEventListener('rubik:loaded', function(ev) {})
```

Now you will be able to access to `window.rubik` will all modules loaded

## Modules

<details><summary>
Analytics
</summary>

> Rubik loads and sets up everything needed to use the [segment wrapper](https://github.mpi-internal.com/scmspain/frontend-all--segment-wrapper)

#### Setup
First add this snippet to the header inside the html

```html
  <script>
    !function(){var analytics=window.analytics=window.analytics||[];if(!analytics.initialize)if(analytics.invoked)window.console&&console.error&&console.error("Segment snippet included twice.");else{analytics.invoked=!0;analytics.methods=["trackSubmit","trackClick","trackLink","trackForm","pageview","identify","reset","group","track","ready","alias","debug","page","once","off","on"];analytics.factory=function(t){return function(){var e=Array.prototype.slice.call(arguments);e.unshift(t);analytics.push(e);return analytics}};for(var t=0;t<analytics.methods.length;t++){var e=analytics.methods[t];analytics[e]=analytics.factory(e)}analytics.load=function(t,e){var n=document.createElement("script");n.type="text/javascript";n.async=!0;n.src="https://cdn.segment.com/analytics.js/v1/"+t+"/analytics.min.js";var a=document.getElementsByTagName("script")[0];a.parentNode.insertBefore(n,a);analytics._loadOptions=e};analytics.SNIPPET_VERSION="4.1.0";

    analytics.load("WRITE KEY"); // ask for the write key
    }}();
  </script>
```

#### Events

##### Identify

```js
  window.analytics.identify("userID abcd...", {
    email:"joe.ayoub@segment.com",
    first_name:"Joe",
    last_name:"Ayoub"
  });
```

##### Track

###### Pages

Wait for the `rubik:loaded` event before firing up the track event for pages

```js
  window.analytics.track("MyCv Experience Form Viewed",{
    page_name:"infojobs.net",
    site:"infojobs.net",
    section:"candidate",
    channel:"my account",
    platform:"web",
    vertical:"jobs",
    page_type:"form",
    status:"edit"
  })
```

##### Clicks

Add an `data-track` attribute with the event you want to track to any DOM element and the click will be tracked automatically

```html
  <div 
    data-track="My Awesome Event" 
    data-properties='{"section":"candidate"}'
    data-options='{"protocols":{"event_version":2}}'>
      track me!
  </div>
  <!-- with &quot; instead of double quote-->
  <div 
    data-track="My Awesome Event" 
    data-properties="{&quot;section&quot;:&quot;candidate&quot;}" 
    data-options="{&quot;protocols&quot;:{&quot;event_version&quot;:2}}">
      track me!
  </div>
```

##### onLoad events A.K.A easy tracking

By creating the `window.__rubik_easy_tracking__` object in your page, rubik will automatically send it as a track event on load. It expects a property called `event_name` to send it as event name, the rest will be send as properties.

```js
window.__rubik_easy_tracking__ = {
  event_name: 'My Event Name',
  section: 'candidate'
}
```

##### Reset

```js
// call this function to reset the browser cookie
document.addEventListener('rubik:loaded', function() {
  window.analytics.reset();
})
```
</details>
<details><summary>
NavOrigen
</summary>

```js
  document.addEventListener('rubik:loaded', function() {
    window.navOrigen.loadCookies()
  })
```

</details>

==> ij-rubik-1.89.0.tgz: package/README.md <==
[![Build Status](https://travis.mpi-internal.com/scmspain/frontend-ij--lib-rubik.svg?token=weuzuyzw6juAMe8gcwxy&branch=master)](https://travis.mpi-internal.com/scmspain/frontend-ij--rubik) ![](https://img.shields.io/badge/automatic-release-brightgreen)


# RubikJS

## Description

JavaScript library meant to abstract core functionality in our [beloved monolith](https://github.schibsted.io/scmspain/all-ij--web-empleo)

## Usage

### Load the script at the end of the body tag in your html file

```html
<html>
<head>
  ...
</head>
<body>
  ...
  <!-- PRE ENVS -->
  <script src="https://unpkg.com/@s-ui/ij-rubik@next/umd/index.js"></script>
  <!-- PRO ENV -->
  <script src="https://unpkg.com/@s-ui/ij-rubik/umd/index.js"></script>
</body>
</html>
```

### Listen to `rubik:loaded` event rubik will sent once its loaded

```js
document.addEventListener('rubik:loaded', function(ev) {})
```

Now you will be able to access to `window.rubik` will all modules loaded

## Modules

<details><summary>
Analytics
</summary>

> Rubik loads and sets up everything needed to use the [segment wrapper](https://github.mpi-internal.com/scmspain/frontend-all--segment-wrapper)

#### Setup
First add this snippet to the header inside the html

```html
  <script>
    !function(){var analytics=window.analytics=window.analytics||[];if(!analytics.initialize)if(analytics.invoked)window.console&&console.error&&console.error("Segment snippet included twice.");else{analytics.invoked=!0;analytics.methods=["trackSubmit","trackClick","trackLink","trackForm","pageview","identify","reset","group","track","ready","alias","debug","page","once","off","on"];analytics.factory=function(t){return function(){var e=Array.prototype.slice.call(arguments);e.unshift(t);analytics.push(e);return analytics}};for(var t=0;t<analytics.methods.length;t++){var e=analytics.methods[t];analytics[e]=analytics.factory(e)}analytics.load=function(t,e){var n=document.createElement("script");n.type="text/javascript";n.async=!0;n.src="https://cdn.segment.com/analytics.js/v1/"+t+"/analytics.min.js";var a=document.getElementsByTagName("script")[0];a.parentNode.insertBefore(n,a);analytics._loadOptions=e};analytics.SNIPPET_VERSION="4.1.0";

    analytics.load("WRITE KEY"); // ask for the write key
    }}();
  </script>
```

#### Events

##### Identify

```js
  window.analytics.identify("userID abcd...", {
    email:"joe.ayoub@segment.com",
    first_name:"Joe",
    last_name:"Ayoub"
  });
```

##### Track

###### Pages

##### onLoad events A.K.A easy tracking

By creating the `window.__rubik_easy_tracking_v2__` object in your page, rubik will automatically send it as a track event on load. It expects a property called `segment_event_name` to send it as event name, the rest will be send as properties.

```js
window.__rubik_easy_tracking_v2__ = {
  segment_event_name: 'My Event Name',
  section: 'candidate'
}
```

Wait for the `rubik:loaded` event before firing up the track event for pages

```js
  window.analytics.track("MyCv Experience Form Viewed",{
    page_name:"infojobs.net",
    site:"infojobs.net",
    section:"candidate",
    channel:"my account",
    platform:"web",
    vertical:"jobs",
    page_type:"form",
    status:"edit"
  })
```

##### Clicks

Add an `data-track` attribute with the event you want to track to any DOM element and the click will be tracked automatically

```html
  <div 
    data-track="My Awesome Event" 
    data-properties='{"section":"candidate"}'
    data-options='{"protocols":{"event_version":2}}'>
      track me!
  </div>
  <!-- with &quot; instead of double quote-->
  <div 
    data-track="My Awesome Event" 
    data-properties="{&quot;section&quot;:&quot;candidate&quot;}" 
    data-options="{&quot;protocols&quot;:{&quot;event_version&quot;:2}}">
      track me!
  </div>
```

##### Reset

```js
// call this function to reset the browser cookie
document.addEventListener('rubik:loaded', function() {
  window.analytics.reset();
})
```
</details>
<details><summary>
NavOrigen
</summary>

```js
  document.addEventListener('rubik:loaded', function() {
    window.navOrigen.loadCookies()
  })
```

</details>


### Local dev

1. Create new umd

```shell
> npm run umd:dev
```

2. Open a http server serving the umd folder

> ⚠️ make sure the server runs in port 5000

``` shell
> npx serve umd
```

3. Open the production page and block the `https://unpkg.com/@s-ui/ij-rubik/umd/index.js` file

4. Run this script to load rubik

```js
var script = document.createElement('script');
script.src = 'http://localhost:5000/index.js'
body.append(script)
```

You can also test the library by publishing a new beta version. In order to do that:

1. Put the **-next.0** suffix to your version

```default
"version": "1.50.0-next.0",
```

2. Execute the publish command

``` shell
> npm publish --tag next
```

3. Check this url **https://unpkg.com/@s-ui/ij-rubik@next/umd/index.js**. In few minutes, it should be redirect to your beta version. In our case:

```default
https://unpkg.com/@s-ui/ij-rubik@1.50.0-next.0/umd/index.js
```

### Release a new version

Once you have merged your changes, the @s-ui/ci tool will automatically release your component. Once this step is completed **https://unpkg.com/@s-ui/ij-rubik/umd/index.js** will need up to 20 minutes to update its cdn's cache and start deliver the new version.
